Hypothesis
==========
Additional tests using `hypothesis <https://hypothesis.readthedocs.io>`_.

Installation
------------
.. code-block:: sh

    pip install -r requirements.in

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
